# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackWorkflowStepEdit(Model):
    """ChargebackWorkflowStepEdit.

    All required parameters must be populated in order to send to Azure.

    :param chargeback_workflow_step_id: Identifier for the chargeback workflow
     step
     If calculateBillWorkflowStepId has a value it will be updated
     If calculateBillWorkflowStepId is null, a new step will be created <span
     class='property-internal'>Required (defined)</span>
    :type chargeback_workflow_step_id: int
    :param chargeback_workflow_step_info: Required. Name given to the
     chargeback workflow step
     Must be unique for a particular type (split or calculation) across all
     workflows <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type chargeback_workflow_step_info: str
    :param chargeback_workflow_step_description: Required. Description for the
     chargeback workflow step <span class='property-internal'>Required</span>
     <span class='property-internal'>Must be between 0 and 255
     characters</span>
    :type chargeback_workflow_step_description: str
    :param chargeback_workflow_step_type: The chargeback type that can be
     assign to this chargeback workflow step.
     When editing a step you cannot change the type <span
     class='property-internal'>One of Split, Calculation </span> <span
     class='property-internal'>Required (defined)</span>
    :type chargeback_workflow_step_type: str
    """

    _validation = {
        'chargeback_workflow_step_info': {'required': True, 'max_length': 64, 'min_length': 0},
        'chargeback_workflow_step_description': {'required': True, 'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'chargeback_workflow_step_id': {'key': 'chargebackWorkflowStepId', 'type': 'int'},
        'chargeback_workflow_step_info': {'key': 'chargebackWorkflowStepInfo', 'type': 'str'},
        'chargeback_workflow_step_description': {'key': 'chargebackWorkflowStepDescription', 'type': 'str'},
        'chargeback_workflow_step_type': {'key': 'chargebackWorkflowStepType', 'type': 'str'},
    }

    def __init__(self, *, chargeback_workflow_step_info: str, chargeback_workflow_step_description: str, chargeback_workflow_step_id: int=None, chargeback_workflow_step_type: str=None, **kwargs) -> None:
        super(ChargebackWorkflowStepEdit, self).__init__(**kwargs)
        self.chargeback_workflow_step_id = chargeback_workflow_step_id
        self.chargeback_workflow_step_info = chargeback_workflow_step_info
        self.chargeback_workflow_step_description = chargeback_workflow_step_description
        self.chargeback_workflow_step_type = chargeback_workflow_step_type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculationResponse(Model):
    """Adding/subtracting calculation involving meters and/or meter groups
    For each type (sum or subtract), expect only one of the properties to be
    populated (e.g. if SumMeters has values, then SumMeterGroups should not).

    :param sum:
    :type sum: ~energycap.sdk.models.SumResponse
    :param subtract:
    :type subtract: ~energycap.sdk.models.SubtractResponse
    """

    _attribute_map = {
        'sum': {'key': 'sum', 'type': 'SumResponse'},
        'subtract': {'key': 'subtract', 'type': 'SubtractResponse'},
    }

    def __init__(self, *, sum=None, subtract=None, **kwargs) -> None:
        super(CalculationResponse, self).__init__(**kwargs)
        self.sum = sum
        self.subtract = subtract



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaselineProcessorRequestBaselineBill(Model):
    """BaselineProcessorRequestBaselineBill.

    :param bill_id: The identifier of the baseline bill
    :type bill_id: int
    :param is_excluded: Indicates if the bill should be included in the
     baseline regression
    :type is_excluded: bool
    """

    _attribute_map = {
        'bill_id': {'key': 'billId', 'type': 'int'},
        'is_excluded': {'key': 'isExcluded', 'type': 'bool'},
    }

    def __init__(self, *, bill_id: int=None, is_excluded: bool=None, **kwargs) -> None:
        super(BaselineProcessorRequestBaselineBill, self).__init__(**kwargs)
        self.bill_id = bill_id
        self.is_excluded = is_excluded



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergySavingsUnit(Model):
    """EnergySavingsUnit.

    :param energy_savings_unit_id: The energy savings unit identifier
    :type energy_savings_unit_id: int
    :param energy_savings_unit_code: The energy savings unit code
    :type energy_savings_unit_code: str
    :param energy_savings_unit_info: The energy savings unit information
    :type energy_savings_unit_info: str
    """

    _attribute_map = {
        'energy_savings_unit_id': {'key': 'energySavingsUnitId', 'type': 'int'},
        'energy_savings_unit_code': {'key': 'energySavingsUnitCode', 'type': 'str'},
        'energy_savings_unit_info': {'key': 'energySavingsUnitInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(EnergySavingsUnit, self).__init__(**kwargs)
        self.energy_savings_unit_id = kwargs.get('energy_savings_unit_id', None)
        self.energy_savings_unit_code = kwargs.get('energy_savings_unit_code', None)
        self.energy_savings_unit_info = kwargs.get('energy_savings_unit_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CostAvoidanceSettings(Model):
    """CostAvoidanceSettings.

    :param minimum_billing_period: Only bills with a billing period greater
     than or equal to this value were included in Cost Avoidance processing
     Will be null unless BillSelectionOption is "BillingPeriod" and Reason is
     "ProcessSavings"
    :type minimum_billing_period: int
    :param skipped_multi_account_if_bills_missing: Indicates if the Cost
     Avoidance processor skipped processing meters with multiple accounts if
     one of the bills was missing
     Will be empty unless Reason is "ProcessSavings"
    :type skipped_multi_account_if_bills_missing: bool
    :param ignored_weather_adjustments: Indicates if weather adjustments were
     ignored when the baseline processor was run
     Will be null unless Reason is "ResetBaseline"
    :type ignored_weather_adjustments: bool
    :param ignored_special_adjustment_type: Defines handling of meter special
     adjustments during Cost Avoidance processing. Can be either of two static
     values OR the special adjustment category that the user chose to skip.
     Will be empty unless Reason is "ProcessSavings"
     Possible static values:
     "NONE" - no special adjustment categories were skipped
     "ALL" - all special adjustment categories were skipped
    :type ignored_special_adjustment_type: str
    :param bill_selection_option: For savings calculation, indicates which
     bills should have been processed
     Will be empty unless Reason is "ProcessSavings"
     Possible values:
     - "AllBills" means all bills were processed
     - "ModifiedOrNotProcessed" means only new bills or bills which have been
     modified since the last time cost avoidance was run have been processed
     - "BillingPeriod" means that only bills with a billing period which is
     greater than or equal to the MinimumBillingPeriod have been processed
    :type bill_selection_option: str
    """

    _attribute_map = {
        'minimum_billing_period': {'key': 'minimumBillingPeriod', 'type': 'int'},
        'skipped_multi_account_if_bills_missing': {'key': 'skippedMultiAccountIfBillsMissing', 'type': 'bool'},
        'ignored_weather_adjustments': {'key': 'ignoredWeatherAdjustments', 'type': 'bool'},
        'ignored_special_adjustment_type': {'key': 'ignoredSpecialAdjustmentType', 'type': 'str'},
        'bill_selection_option': {'key': 'billSelectionOption', 'type': 'str'},
    }

    def __init__(self, *, minimum_billing_period: int=None, skipped_multi_account_if_bills_missing: bool=None, ignored_weather_adjustments: bool=None, ignored_special_adjustment_type: str=None, bill_selection_option: str=None, **kwargs) -> None:
        super(CostAvoidanceSettings, self).__init__(**kwargs)
        self.minimum_billing_period = minimum_billing_period
        self.skipped_multi_account_if_bills_missing = skipped_multi_account_if_bills_missing
        self.ignored_weather_adjustments = ignored_weather_adjustments
        self.ignored_special_adjustment_type = ignored_special_adjustment_type
        self.bill_selection_option = bill_selection_option



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PostalCodeResponseWeatherStation(Model):
    """PostalCodeResponseWeatherStation.

    :param weather_station_id: The weather station Id
    :type weather_station_id: int
    :param web_station_id: The web station Id
    :type web_station_id: int
    :param weather_station_code: The weather station code
    :type weather_station_code: str
    :param city: The city of the weather station
    :type city: str
    :param state: The state of the weather station
    :type state: str
    :param country: The country of the weather station
    :type country: str
    """

    _attribute_map = {
        'weather_station_id': {'key': 'weatherStationId', 'type': 'int'},
        'web_station_id': {'key': 'webStationId', 'type': 'int'},
        'weather_station_code': {'key': 'weatherStationCode', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(PostalCodeResponseWeatherStation, self).__init__(**kwargs)
        self.weather_station_id = kwargs.get('weather_station_id', None)
        self.web_station_id = kwargs.get('web_station_id', None)
        self.weather_station_code = kwargs.get('weather_station_code', None)
        self.city = kwargs.get('city', None)
        self.state = kwargs.get('state', None)
        self.country = kwargs.get('country', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NotificationDetailsResponse(Model):
    """NotificationDetailsResponse.

    :param message: The full notification message
    :type message: str
    :param created_by_user:
    :type created_by_user: ~energycap.sdk.models.UserChild
    :param primary_action:
    :type primary_action:
     ~energycap.sdk.models.NotificationActionButtonResponse
    :param secondary_action:
    :type secondary_action:
     ~energycap.sdk.models.NotificationActionButtonResponse
    :param notification_id: The id of the notification
    :type notification_id: long
    :param read: True if the notification has been read
    :type read: bool
    :param archived: True if the notification has been archived
    :type archived: bool
    :param subject: Subject of the notification
    :type subject: str
    :param created_date: The date and time the notification was generated
    :type created_date: datetime
    :param notification_type:
    :type notification_type: ~energycap.sdk.models.NotificationType
    """

    _attribute_map = {
        'message': {'key': 'message', 'type': 'str'},
        'created_by_user': {'key': 'createdByUser', 'type': 'UserChild'},
        'primary_action': {'key': 'primaryAction', 'type': 'NotificationActionButtonResponse'},
        'secondary_action': {'key': 'secondaryAction', 'type': 'NotificationActionButtonResponse'},
        'notification_id': {'key': 'notificationId', 'type': 'long'},
        'read': {'key': 'read', 'type': 'bool'},
        'archived': {'key': 'archived', 'type': 'bool'},
        'subject': {'key': 'subject', 'type': 'str'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'notification_type': {'key': 'notificationType', 'type': 'NotificationType'},
    }

    def __init__(self, **kwargs):
        super(NotificationDetailsResponse, self).__init__(**kwargs)
        self.message = kwargs.get('message', None)
        self.created_by_user = kwargs.get('created_by_user', None)
        self.primary_action = kwargs.get('primary_action', None)
        self.secondary_action = kwargs.get('secondary_action', None)
        self.notification_id = kwargs.get('notification_id', None)
        self.read = kwargs.get('read', None)
        self.archived = kwargs.get('archived', None)
        self.subject = kwargs.get('subject', None)
        self.created_date = kwargs.get('created_date', None)
        self.notification_type = kwargs.get('notification_type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ExportBillsClassPermission(Model):
    """ExportBillsClassPermission.

    :param edit:
    :type edit: bool
    :param delete:
    :type delete: bool
    :param run:
    :type run: bool
    """

    _attribute_map = {
        'edit': {'key': 'edit', 'type': 'bool'},
        'delete': {'key': 'delete', 'type': 'bool'},
        'run': {'key': 'run', 'type': 'bool'},
    }

    def __init__(self, *, edit: bool=None, delete: bool=None, run: bool=None, **kwargs) -> None:
        super(ExportBillsClassPermission, self).__init__(**kwargs)
        self.edit = edit
        self.delete = delete
        self.run = run



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DynamicListRequest(Model):
    """DynamicListRequest.

    :param filters: Filters to apply to the dynamic list when initializing it
     <span class='property-internal'>Cannot be Empty</span>
    :type filters: list[~energycap.sdk.models.QuickFilter]
    :param reset_columns: Flag indicating whether or not to initialize the
     dynamic list column definitions
    :type reset_columns: bool
    """

    _attribute_map = {
        'filters': {'key': 'filters', 'type': '[QuickFilter]'},
        'reset_columns': {'key': 'resetColumns', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(DynamicListRequest, self).__init__(**kwargs)
        self.filters = kwargs.get('filters', None)
        self.reset_columns = kwargs.get('reset_columns', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportDistributionLogDetailsResponse(Model):
    """ReportDistributionLogDetailsResponse.

    :param email_settings:
    :type email_settings:
     ~energycap.sdk.models.ReportDistributionLogEmailSettings
    :param report_settings:
    :type report_settings:
     ~energycap.sdk.models.ReportDistributionLogReportSettings
    :param errors: Detailed errors that may have occurred during report
     distribution run
    :type errors: str
    """

    _attribute_map = {
        'email_settings': {'key': 'emailSettings', 'type': 'ReportDistributionLogEmailSettings'},
        'report_settings': {'key': 'reportSettings', 'type': 'ReportDistributionLogReportSettings'},
        'errors': {'key': 'errors', 'type': 'str'},
    }

    def __init__(self, *, email_settings=None, report_settings=None, errors: str=None, **kwargs) -> None:
        super(ReportDistributionLogDetailsResponse, self).__init__(**kwargs)
        self.email_settings = email_settings
        self.report_settings = report_settings
        self.errors = errors



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestTargetComparisonMonthly(Model):
    """PlaceDigestTargetComparisonMonthly.

    :param target_year: Target Year
    :type target_year: int
    :param target_label: Target Label
    :type target_label: str
    :param results: Monthly Target Data
    :type results:
     list[~energycap.sdk.models.PlaceDigestTargetComparisonMonthlyResults]
    """

    _attribute_map = {
        'target_year': {'key': 'targetYear', 'type': 'int'},
        'target_label': {'key': 'targetLabel', 'type': 'str'},
        'results': {'key': 'results', 'type': '[PlaceDigestTargetComparisonMonthlyResults]'},
    }

    def __init__(self, *, target_year: int=None, target_label: str=None, results=None, **kwargs) -> None:
        super(PlaceDigestTargetComparisonMonthly, self).__init__(**kwargs)
        self.target_year = target_year
        self.target_label = target_label
        self.results = results



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackWorkflowSettings(Model):
    """Represents workflow settings for chargebacks.

    All required parameters must be populated in order to send to Azure.

    :param allow_advanced_chargeback_settings: Required. Allow or prevent the
     "advanced" dialog to be displayed when running the chargeback processor
     <span class='property-internal'>Required</span>
    :type allow_advanced_chargeback_settings: bool
    """

    _validation = {
        'allow_advanced_chargeback_settings': {'required': True},
    }

    _attribute_map = {
        'allow_advanced_chargeback_settings': {'key': 'allowAdvancedChargebackSettings', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(ChargebackWorkflowSettings, self).__init__(**kwargs)
        self.allow_advanced_chargeback_settings = kwargs.get('allow_advanced_chargeback_settings', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class OtherSavingsResponse(Model):
    """OtherSavingsResponse.

    :param other_savings_id: Other savings identifier
    :type other_savings_id: int
    :param frequency: Other savings frequency
     Possible values are: one-time, continuous, and recurring
    :type frequency: str
    :param other_savings_category:
    :type other_savings_category: ~energycap.sdk.models.OtherSavingsCategory
    :param description: Description
    :type description: str
    :param start_period: Begin period for the other savings
    :type start_period: int
    :param end_period: End period for the other savings
    :type end_period: int
    :param annnual_cycle_start_month: Month the other savings should begin
     This is only set when the other savings type is recurring
    :type annnual_cycle_start_month: int
    :param annual_cycle_end_month: Month the other savings should end
     This is only set when the other savings type is recurring
    :type annual_cycle_end_month: int
    :param value: Amount saved
    :type value: float
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    :param created_date: Create date
    :type created_date: datetime
    :param modified_by:
    :type modified_by: ~energycap.sdk.models.UserChild
    :param modified_date: Last modified date
    :type modified_date: datetime
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'other_savings_id': {'key': 'otherSavingsId', 'type': 'int'},
        'frequency': {'key': 'frequency', 'type': 'str'},
        'other_savings_category': {'key': 'otherSavingsCategory', 'type': 'OtherSavingsCategory'},
        'description': {'key': 'description', 'type': 'str'},
        'start_period': {'key': 'startPeriod', 'type': 'int'},
        'end_period': {'key': 'endPeriod', 'type': 'int'},
        'annnual_cycle_start_month': {'key': 'annnualCycleStartMonth', 'type': 'int'},
        'annual_cycle_end_month': {'key': 'annualCycleEndMonth', 'type': 'int'},
        'value': {'key': 'value', 'type': 'float'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'modified_by': {'key': 'modifiedBy', 'type': 'UserChild'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
    }

    def __init__(self, **kwargs):
        super(OtherSavingsResponse, self).__init__(**kwargs)
        self.other_savings_id = kwargs.get('other_savings_id', None)
        self.frequency = kwargs.get('frequency', None)
        self.other_savings_category = kwargs.get('other_savings_category', None)
        self.description = kwargs.get('description', None)
        self.start_period = kwargs.get('start_period', None)
        self.end_period = kwargs.get('end_period', None)
        self.annnual_cycle_start_month = kwargs.get('annnual_cycle_start_month', None)
        self.annual_cycle_end_month = kwargs.get('annual_cycle_end_month', None)
        self.value = kwargs.get('value', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_date = kwargs.get('created_date', None)
        self.modified_by = kwargs.get('modified_by', None)
        self.modified_date = kwargs.get('modified_date', None)
        self.cost_unit = kwargs.get('cost_unit', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BenchmarkSettingsEdit(Model):
    """BenchmarkSettingsEdit.

    :param benchmark1:
    :type benchmark1: ~energycap.sdk.models.BenchmarkEdit
    :param benchmark2:
    :type benchmark2: ~energycap.sdk.models.BenchmarkEdit
    :param benchmark3:
    :type benchmark3: ~energycap.sdk.models.BenchmarkEdit
    """

    _attribute_map = {
        'benchmark1': {'key': 'benchmark1', 'type': 'BenchmarkEdit'},
        'benchmark2': {'key': 'benchmark2', 'type': 'BenchmarkEdit'},
        'benchmark3': {'key': 'benchmark3', 'type': 'BenchmarkEdit'},
    }

    def __init__(self, *, benchmark1=None, benchmark2=None, benchmark3=None, **kwargs) -> None:
        super(BenchmarkSettingsEdit, self).__init__(**kwargs)
        self.benchmark1 = benchmark1
        self.benchmark2 = benchmark2
        self.benchmark3 = benchmark3



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackWorkflowDigestResponse(Model):
    """ChargebackWorkflowDigestResponse.

    :param chargeback_workflow_step:
    :type chargeback_workflow_step:
     ~energycap.sdk.models.ChargebackWorkflowStepChild
    :param results: The list of digest results for the latest task executed in
     the specified billing period.
    :type results: list[~energycap.sdk.models.ChargebackWorkflowDigestChild]
    """

    _attribute_map = {
        'chargeback_workflow_step': {'key': 'chargebackWorkflowStep', 'type': 'ChargebackWorkflowStepChild'},
        'results': {'key': 'results', 'type': '[ChargebackWorkflowDigestChild]'},
    }

    def __init__(self, *, chargeback_workflow_step=None, results=None, **kwargs) -> None:
        super(ChargebackWorkflowDigestResponse, self).__init__(**kwargs)
        self.chargeback_workflow_step = chargeback_workflow_step
        self.results = results



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportSubscriptionRequest(Model):
    """ReportSubscriptionRequest.

    All required parameters must be populated in order to send to Azure.

    :param email_subject: Required. The subject line of the email <span
     class='property-internal'>Must be between 0 and 255 characters</span>
     <span class='property-internal'>Required</span>
    :type email_subject: str
    :param email_message: Required. The body of the email <span
     class='property-internal'>Required</span>
    :type email_message: str
    :param report_subscription_schedule_type_id: Required. The schedule type
     of the report
     Values may be:
     Daily: 1
     Weekly: 2
     Monthly: 3
     Quarterly: 4 <span class='property-internal'>Required</span> <span
     class='property-internal'>One of 1, 2, 3, 4 </span>
    :type report_subscription_schedule_type_id: int
    :param day_indicator_value: Required. Indicates when to send the report
     for the given schedule type
     Values may be:
     Daily: 0
     Weekly: Day of Week - 0 (Sunday) to 6 (Saturday)
     Monthly: Day of Month - 1 to 28
     Quarterly: Month in Quarter - 1, 2, or 3 <span
     class='property-internal'>Must be between 0 and 28</span> <span
     class='property-internal'>Required</span>
    :type day_indicator_value: int
    :param only_send_if_data: Required. Indicates whether or not to email a
     report if it contains no data.
     When set to true, the subscribed report will not be emailed, if the report
     does not contain data.
     When set to false, if the requested report has no data, it will still be
     sent. <span class='property-internal'>Required</span>
    :type only_send_if_data: bool
    :param report_format: Required. The format in which the generated report
     should be downloaded <span class='property-internal'>Required</span> <span
     class='property-internal'>One of Excel, Excel data only, Csv, PDF, Word
     </span>
    :type report_format: str
    """

    _validation = {
        'email_subject': {'required': True, 'max_length': 255, 'min_length': 0},
        'email_message': {'required': True},
        'report_subscription_schedule_type_id': {'required': True},
        'day_indicator_value': {'required': True, 'maximum': 28, 'minimum': 0},
        'only_send_if_data': {'required': True},
        'report_format': {'required': True},
    }

    _attribute_map = {
        'email_subject': {'key': 'emailSubject', 'type': 'str'},
        'email_message': {'key': 'emailMessage', 'type': 'str'},
        'report_subscription_schedule_type_id': {'key': 'reportSubscriptionScheduleTypeId', 'type': 'int'},
        'day_indicator_value': {'key': 'dayIndicatorValue', 'type': 'int'},
        'only_send_if_data': {'key': 'onlySendIfData', 'type': 'bool'},
        'report_format': {'key': 'reportFormat', 'type': 'str'},
    }

    def __init__(self, *, email_subject: str, email_message: str, report_subscription_schedule_type_id: int, day_indicator_value: int, only_send_if_data: bool, report_format: str, **kwargs) -> None:
        super(ReportSubscriptionRequest, self).__init__(**kwargs)
        self.email_subject = email_subject
        self.email_message = email_message
        self.report_subscription_schedule_type_id = report_subscription_schedule_type_id
        self.day_indicator_value = day_indicator_value
        self.only_send_if_data = only_send_if_data
        self.report_format = report_format



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterSerialNumberHistoryRequest(Model):
    """MeterSerialNumberHistoryRequest.

    All required parameters must be populated in order to send to Azure.

    :param new_serial_number: Required. Serial number that will replace the
     existing one <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type new_serial_number: str
    :param serial_number_change_date: Date that serial number changed <span
     class='property-internal'>Required (defined)</span>
    :type serial_number_change_date: datetime
    """

    _validation = {
        'new_serial_number': {'required': True, 'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'new_serial_number': {'key': 'newSerialNumber', 'type': 'str'},
        'serial_number_change_date': {'key': 'serialNumberChangeDate', 'type': 'iso-8601'},
    }

    def __init__(self, *, new_serial_number: str, serial_number_change_date=None, **kwargs) -> None:
        super(MeterSerialNumberHistoryRequest, self).__init__(**kwargs)
        self.new_serial_number = new_serial_number
        self.serial_number_change_date = serial_number_change_date



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillUnexport(Model):
    """BillUnexport.

    All required parameters must be populated in order to send to Azure.

    :param bill_ids: Required.  <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Cannot be Empty</span>
    :type bill_ids: list[int]
    :param export_mode: Required.  <span
     class='property-internal'>Required</span> <span
     class='property-internal'>One of ap, gl </span>
    :type export_mode: str
    """

    _validation = {
        'bill_ids': {'required': True},
        'export_mode': {'required': True},
    }

    _attribute_map = {
        'bill_ids': {'key': 'billIds', 'type': '[int]'},
        'export_mode': {'key': 'exportMode', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(BillUnexport, self).__init__(**kwargs)
        self.bill_ids = kwargs.get('bill_ids', None)
        self.export_mode = kwargs.get('export_mode', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterSerialNumberHistoryResponse(Model):
    """MeterSerialNumberHistoryResponse.

    :param meter_id: Meter identifier <span class='property-internal'>Required
     (defined)</span>
    :type meter_id: int
    :param serial_number: Serial number of the meter <span
     class='property-internal'>Required (defined)</span>
    :type serial_number: str
    :param serial_number_history:
    :type serial_number_history:
     ~energycap.sdk.models.MeterSerialNumberHistoryChild
    """

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'serial_number': {'key': 'serialNumber', 'type': 'str'},
        'serial_number_history': {'key': 'serialNumberHistory', 'type': 'MeterSerialNumberHistoryChild'},
    }

    def __init__(self, *, meter_id: int=None, serial_number: str=None, serial_number_history=None, **kwargs) -> None:
        super(MeterSerialNumberHistoryResponse, self).__init__(**kwargs)
        self.meter_id = meter_id
        self.serial_number = serial_number
        self.serial_number_history = serial_number_history



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NamedPeriod(Model):
    """This class represents a date period (YYYYMM) which could be an accounting
    period or a billing/calendar period.

    :param period_name: Name of the period to be displayed
     Should be empty if billing period
    :type period_name: str
    :param period: Value of the period in format (YYYYPP)
     PP may be a calendar month (e.g. 01-12) but it could be an accounting
     period (e.g. 01-13)
    :type period: int
    """

    _attribute_map = {
        'period_name': {'key': 'periodName', 'type': 'str'},
        'period': {'key': 'period', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(NamedPeriod, self).__init__(**kwargs)
        self.period_name = kwargs.get('period_name', None)
        self.period = kwargs.get('period', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListActionCustom(Model):
    """ListActionCustom.

    All required parameters must be populated in order to send to Azure.

    :param webhook_id: Required. The webhook identifier that represents the
     custom bill action <span class='property-internal'>Required</span>
    :type webhook_id: int
    """

    _validation = {
        'webhook_id': {'required': True},
    }

    _attribute_map = {
        'webhook_id': {'key': 'webhookId', 'type': 'int'},
    }

    def __init__(self, *, webhook_id: int, **kwargs) -> None:
        super(ListActionCustom, self).__init__(**kwargs)
        self.webhook_id = webhook_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterDigestGHGYearlyResponseGHGScope(Model):
    """MeterDigestGHGYearlyResponseGHGScope.

    :param ghg_scope_id: GHG scope identifier
    :type ghg_scope_id: int
    :param ghg_scope_code: GHG scope code
    :type ghg_scope_code: str
    :param ghg_scope_info: GHG scope info
    :type ghg_scope_info: str
    :param ghg_scope_type_code: GHG scope type code
    :type ghg_scope_type_code: str
    :param ghg_scope_type_info: GHG scope type code
    :type ghg_scope_type_info: str
    """

    _attribute_map = {
        'ghg_scope_id': {'key': 'ghgScopeId', 'type': 'int'},
        'ghg_scope_code': {'key': 'ghgScopeCode', 'type': 'str'},
        'ghg_scope_info': {'key': 'ghgScopeInfo', 'type': 'str'},
        'ghg_scope_type_code': {'key': 'ghgScopeTypeCode', 'type': 'str'},
        'ghg_scope_type_info': {'key': 'ghgScopeTypeInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(MeterDigestGHGYearlyResponseGHGScope, self).__init__(**kwargs)
        self.ghg_scope_id = kwargs.get('ghg_scope_id', None)
        self.ghg_scope_code = kwargs.get('ghg_scope_code', None)
        self.ghg_scope_info = kwargs.get('ghg_scope_info', None)
        self.ghg_scope_type_code = kwargs.get('ghg_scope_type_code', None)
        self.ghg_scope_type_info = kwargs.get('ghg_scope_type_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestActualAndCalendarizedMonthlyResponseCommodityResults(Model):
    """PlaceDigestActualAndCalendarizedMonthlyResponseCommodityResults.

    :param period_name: Calendar Period Name
    :type period_name: str
    :param calendar_period: Calendar Period
    :type calendar_period: int
    :param calendar_year: Calendar Year
    :type calendar_year: int
    :param fiscal_period: Fiscal Period
    :type fiscal_period: int
    :param fiscal_year: Fiscal Year
    :type fiscal_year: int
    :param total_cost: Total Cost
    :type total_cost: float
    :param common_use: Common Use
    :type common_use: float
    :param common_use_unit_cost: Common Use Unit Cost
    :type common_use_unit_cost: float
    :param global_use: Global Use
    :type global_use: float
    :param global_use_unit_cost: Global Use Unit Cost
    :type global_use_unit_cost: float
    :param common_demand: Common Demand
    :type common_demand: float
    :param common_demand_unit_cost: Common Demand Unit Cost
    :type common_demand_unit_cost: float
    """

    _attribute_map = {
        'period_name': {'key': 'periodName', 'type': 'str'},
        'calendar_period': {'key': 'calendarPeriod', 'type': 'int'},
        'calendar_year': {'key': 'calendarYear', 'type': 'int'},
        'fiscal_period': {'key': 'fiscalPeriod', 'type': 'int'},
        'fiscal_year': {'key': 'fiscalYear', 'type': 'int'},
        'total_cost': {'key': 'totalCost', 'type': 'float'},
        'common_use': {'key': 'commonUse', 'type': 'float'},
        'common_use_unit_cost': {'key': 'commonUseUnitCost', 'type': 'float'},
        'global_use': {'key': 'globalUse', 'type': 'float'},
        'global_use_unit_cost': {'key': 'globalUseUnitCost', 'type': 'float'},
        'common_demand': {'key': 'commonDemand', 'type': 'float'},
        'common_demand_unit_cost': {'key': 'commonDemandUnitCost', 'type': 'float'},
    }

    def __init__(self, *, period_name: str=None, calendar_period: int=None, calendar_year: int=None, fiscal_period: int=None, fiscal_year: int=None, total_cost: float=None, common_use: float=None, common_use_unit_cost: float=None, global_use: float=None, global_use_unit_cost: float=None, common_demand: float=None, common_demand_unit_cost: float=None, **kwargs) -> None:
        super(PlaceDigestActualAndCalendarizedMonthlyResponseCommodityResults, self).__init__(**kwargs)
        self.period_name = period_name
        self.calendar_period = calendar_period
        self.calendar_year = calendar_year
        self.fiscal_period = fiscal_period
        self.fiscal_year = fiscal_year
        self.total_cost = total_cost
        self.common_use = common_use
        self.common_use_unit_cost = common_use_unit_cost
        self.global_use = global_use
        self.global_use_unit_cost = global_use_unit_cost
        self.common_demand = common_demand
        self.common_demand_unit_cost = common_demand_unit_cost



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UDFValue(Model):
    """UDFValue.

    :param udf_id: udfId of the UDF being edited <span
     class='property-internal'>Required (defined)</span>
    :type udf_id: int
    :param value:  <span class='property-internal'>Required (defined)</span>
    :type value: str
    """

    _attribute_map = {
        'udf_id': {'key': 'udfId', 'type': 'int'},
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, *, udf_id: int=None, value: str=None, **kwargs) -> None:
        super(UDFValue, self).__init__(**kwargs)
        self.udf_id = udf_id
        self.value = value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HierarchicalCostCenters(Model):
    """HierarchicalCostCenters.

    :param parent_id: The cost center's parent
    :type parent_id: int
    :param cost_center_id: The cost center's primary ID
    :type cost_center_id: int
    :param cost_center_info: CostCenterInfo
    :type cost_center_info: str
    :param cost_center_code: CostCenterCode
    :type cost_center_code: str
    :param has_children: If this costCenter has any children, either accounts
     or costCenters
    :type has_children: bool
    :param has_cost_center_children: If this costCenter has any costCenter
     children
    :type has_cost_center_children: bool
    :param has_account_children: If this costCenter has any account children
    :type has_account_children: bool
    :param has_active_children: If this costCenter has any costCenter children
     or active account children
    :type has_active_children: bool
    :param has_active_account_children: If this costCenter has any active
     account children
    :type has_active_account_children: bool
    :param account_children: List of account children
    :type account_children: list[~energycap.sdk.models.CostCenterAccountChild]
    :param cost_center_children: List of costCenter children
    :type cost_center_children:
     list[~energycap.sdk.models.HierarchicalCostCenters2]
    """

    _attribute_map = {
        'parent_id': {'key': 'parentId', 'type': 'int'},
        'cost_center_id': {'key': 'costCenterId', 'type': 'int'},
        'cost_center_info': {'key': 'costCenterInfo', 'type': 'str'},
        'cost_center_code': {'key': 'costCenterCode', 'type': 'str'},
        'has_children': {'key': 'hasChildren', 'type': 'bool'},
        'has_cost_center_children': {'key': 'hasCostCenterChildren', 'type': 'bool'},
        'has_account_children': {'key': 'hasAccountChildren', 'type': 'bool'},
        'has_active_children': {'key': 'hasActiveChildren', 'type': 'bool'},
        'has_active_account_children': {'key': 'hasActiveAccountChildren', 'type': 'bool'},
        'account_children': {'key': 'accountChildren', 'type': '[CostCenterAccountChild]'},
        'cost_center_children': {'key': 'costCenterChildren', 'type': '[HierarchicalCostCenters2]'},
    }

    def __init__(self, *, parent_id: int=None, cost_center_id: int=None, cost_center_info: str=None, cost_center_code: str=None, has_children: bool=None, has_cost_center_children: bool=None, has_account_children: bool=None, has_active_children: bool=None, has_active_account_children: bool=None, account_children=None, cost_center_children=None, **kwargs) -> None:
        super(HierarchicalCostCenters, self).__init__(**kwargs)
        self.parent_id = parent_id
        self.cost_center_id = cost_center_id
        self.cost_center_info = cost_center_info
        self.cost_center_code = cost_center_code
        self.has_children = has_children
        self.has_cost_center_children = has_cost_center_children
        self.has_account_children = has_account_children
        self.has_active_children = has_active_children
        self.has_active_account_children = has_active_account_children
        self.account_children = account_children
        self.cost_center_children = cost_center_children



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SendDataAccessReleaseRequest(Model):
    """SendDataAccessReleaseRequest.

    All required parameters must be populated in order to send to Azure.

    :param reply_to: Required. Sets the reply-to email address <span
     class='property-internal'>Must be between 0 and 128 characters</span>
     <span class='property-internal'>Required</span>
    :type reply_to: str
    :param recipients: The list of recipient email addresses <span
     class='property-internal'>Cannot be Empty</span>
    :type recipients: list[str]
    :param subject: Required. The subject of the data access release request
     email <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type subject: str
    :param message: Required. The body of the data access release request
     email <span class='property-internal'>Required</span>
    :type message: str
    """

    _validation = {
        'reply_to': {'required': True, 'max_length': 128, 'min_length': 0},
        'subject': {'required': True, 'max_length': 255, 'min_length': 0},
        'message': {'required': True},
    }

    _attribute_map = {
        'reply_to': {'key': 'replyTo', 'type': 'str'},
        'recipients': {'key': 'recipients', 'type': '[str]'},
        'subject': {'key': 'subject', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(SendDataAccessReleaseRequest, self).__init__(**kwargs)
        self.reply_to = kwargs.get('reply_to', None)
        self.recipients = kwargs.get('recipients', None)
        self.subject = kwargs.get('subject', None)
        self.message = kwargs.get('message', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestActualAndCalendarizedYearlyResponseTargetComparison(Model):
    """PlaceDigestActualAndCalendarizedYearlyResponseTargetComparison.

    :param target_year: Target year
    :type target_year: int
    :param target_label: Target label
    :type target_label: str
    :param total_cost: Total cost for the target year
    :type total_cost: float
    :param total_cost_ytd: Total cost for the target year up to the target
     period that corresponds to the current period
    :type total_cost_ytd: float
    :param global_use: Total use for the target year
    :type global_use: float
    :param global_use_ytd: Total use for the target year up to the target
     period that corresponds to the current period
    :type global_use_ytd: float
    """

    _attribute_map = {
        'target_year': {'key': 'targetYear', 'type': 'int'},
        'target_label': {'key': 'targetLabel', 'type': 'str'},
        'total_cost': {'key': 'totalCost', 'type': 'float'},
        'total_cost_ytd': {'key': 'totalCostYtd', 'type': 'float'},
        'global_use': {'key': 'globalUse', 'type': 'float'},
        'global_use_ytd': {'key': 'globalUseYtd', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(PlaceDigestActualAndCalendarizedYearlyResponseTargetComparison, self).__init__(**kwargs)
        self.target_year = kwargs.get('target_year', None)
        self.target_label = kwargs.get('target_label', None)
        self.total_cost = kwargs.get('total_cost', None)
        self.total_cost_ytd = kwargs.get('total_cost_ytd', None)
        self.global_use = kwargs.get('global_use', None)
        self.global_use_ytd = kwargs.get('global_use_ytd', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillImportProfileRequest(Model):
    """BillImportProfileRequest.

    All required parameters must be populated in order to send to Azure.

    :param profile_code: Required.  <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type profile_code: str
    :param column_mapping:
    :type column_mapping: ~energycap.sdk.models.BillImportProfileColumnMapping
    """

    _validation = {
        'profile_code': {'required': True, 'max_length': 64, 'min_length': 0},
    }

    _attribute_map = {
        'profile_code': {'key': 'profileCode', 'type': 'str'},
        'column_mapping': {'key': 'columnMapping', 'type': 'BillImportProfileColumnMapping'},
    }

    def __init__(self, **kwargs):
        super(BillImportProfileRequest, self).__init__(**kwargs)
        self.profile_code = kwargs.get('profile_code', None)
        self.column_mapping = kwargs.get('column_mapping', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountCodeHistoryRequest(Model):
    """AccountCodeHistoryRequest.

    All required parameters must be populated in order to send to Azure.

    :param new_account_code: Required. Account code that will replace the
     existing one <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type new_account_code: str
    :param new_account_info: Account info that can replace the existing info
     <span class='property-internal'>Must be between 0 and 50 characters</span>
     <span class='property-internal'>Required (defined)</span>
    :type new_account_info: str
    :param code_change_date: Date that the account code was changed <span
     class='property-internal'>Required (defined)</span>
    :type code_change_date: datetime
    """

    _validation = {
        'new_account_code': {'required': True, 'max_length': 50, 'min_length': 0},
        'new_account_info': {'max_length': 50, 'min_length': 0},
    }

    _attribute_map = {
        'new_account_code': {'key': 'newAccountCode', 'type': 'str'},
        'new_account_info': {'key': 'newAccountInfo', 'type': 'str'},
        'code_change_date': {'key': 'codeChangeDate', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(AccountCodeHistoryRequest, self).__init__(**kwargs)
        self.new_account_code = kwargs.get('new_account_code', None)
        self.new_account_info = kwargs.get('new_account_info', None)
        self.code_change_date = kwargs.get('code_change_date', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpecialAdjustmentType(Model):
    """SpecialAdjustmentType.

    :param special_adjustment_type_id: Special Adjustment type identifier
    :type special_adjustment_type_id: int
    :param special_adjustment_type_code: Special Adjustment type code
    :type special_adjustment_type_code: str
    :param special_adjustment_type_info: Special Adjustment type name
    :type special_adjustment_type_info: str
    """

    _attribute_map = {
        'special_adjustment_type_id': {'key': 'specialAdjustmentTypeId', 'type': 'int'},
        'special_adjustment_type_code': {'key': 'specialAdjustmentTypeCode', 'type': 'str'},
        'special_adjustment_type_info': {'key': 'specialAdjustmentTypeInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(SpecialAdjustmentType, self).__init__(**kwargs)
        self.special_adjustment_type_id = kwargs.get('special_adjustment_type_id', None)
        self.special_adjustment_type_code = kwargs.get('special_adjustment_type_code', None)
        self.special_adjustment_type_info = kwargs.get('special_adjustment_type_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyProjectType(Model):
    """EnergyProjectType.

    :param energy_project_type_id: The energy project type identifier
    :type energy_project_type_id: int
    :param energy_project_type_code: The energy project type code
    :type energy_project_type_code: str
    :param energy_project_type_info: The energy project type  info
    :type energy_project_type_info: str
    """

    _attribute_map = {
        'energy_project_type_id': {'key': 'energyProjectTypeId', 'type': 'int'},
        'energy_project_type_code': {'key': 'energyProjectTypeCode', 'type': 'str'},
        'energy_project_type_info': {'key': 'energyProjectTypeInfo', 'type': 'str'},
    }

    def __init__(self, *, energy_project_type_id: int=None, energy_project_type_code: str=None, energy_project_type_info: str=None, **kwargs) -> None:
        super(EnergyProjectType, self).__init__(**kwargs)
        self.energy_project_type_id = energy_project_type_id
        self.energy_project_type_code = energy_project_type_code
        self.energy_project_type_info = energy_project_type_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NotificationCategory(Model):
    """NotificationCategory.

    :param notification_category_id: The id of the notification category
    :type notification_category_id: int
    :param notification_category_info: The notification category name
    :type notification_category_info: str
    :param notification_category_description: A description of the
     notification category
    :type notification_category_description: str
    """

    _attribute_map = {
        'notification_category_id': {'key': 'notificationCategoryId', 'type': 'int'},
        'notification_category_info': {'key': 'notificationCategoryInfo', 'type': 'str'},
        'notification_category_description': {'key': 'notificationCategoryDescription', 'type': 'str'},
    }

    def __init__(self, *, notification_category_id: int=None, notification_category_info: str=None, notification_category_description: str=None, **kwargs) -> None:
        super(NotificationCategory, self).__init__(**kwargs)
        self.notification_category_id = notification_category_id
        self.notification_category_info = notification_category_info
        self.notification_category_description = notification_category_description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DynamicPercentageBillSplit(Model):
    """Defines details for a dynamic percentage split of use, cost, or both based
    on the use or cost values of the meters in the destination meter group.

    All required parameters must be populated in order to send to Azure.

    :param destination_meter_group_id: Required. ID of a meter group to
     receive the results of the split bill. <span
     class='property-internal'>Required</span>
    :type destination_meter_group_id: int
    :param source_value_to_split: Required. Value to distribute to the
     destination meters. <span class='property-internal'>Required</span> <span
     class='property-internal'>One of use, cost, useAndCost </span>
    :type source_value_to_split: str
    :param destination_share_value: Required. Value to define how dynamic
     percentages are calculated. <span
     class='property-internal'>Required</span> <span
     class='property-internal'>One of use, cost </span>
    :type destination_share_value: str
    """

    _validation = {
        'destination_meter_group_id': {'required': True},
        'source_value_to_split': {'required': True},
        'destination_share_value': {'required': True},
    }

    _attribute_map = {
        'destination_meter_group_id': {'key': 'destinationMeterGroupId', 'type': 'int'},
        'source_value_to_split': {'key': 'sourceValueToSplit', 'type': 'str'},
        'destination_share_value': {'key': 'destinationShareValue', 'type': 'str'},
    }

    def __init__(self, *, destination_meter_group_id: int, source_value_to_split: str, destination_share_value: str, **kwargs) -> None:
        super(DynamicPercentageBillSplit, self).__init__(**kwargs)
        self.destination_meter_group_id = destination_meter_group_id
        self.source_value_to_split = source_value_to_split
        self.destination_share_value = destination_share_value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillMeterEdit(Model):
    """BillMeterEdit.

    All required parameters must be populated in order to send to Azure.

    :param meter_id: Required. The meter the line items are assigned to <span
     class='property-internal'>Required</span>
    :type meter_id: int
    :param body_lines: Required.  <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Cannot be Empty</span>
    :type body_lines: list[~energycap.sdk.models.BillMeterBodyLineEdit]
    """

    _validation = {
        'meter_id': {'required': True},
        'body_lines': {'required': True},
    }

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'body_lines': {'key': 'bodyLines', 'type': '[BillMeterBodyLineEdit]'},
    }

    def __init__(self, *, meter_id: int, body_lines, **kwargs) -> None:
        super(BillMeterEdit, self).__init__(**kwargs)
        self.meter_id = meter_id
        self.body_lines = body_lines



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterSearchRequest(Model):
    """Parameters to use for performing a utility platform meter search.

    :param search_type: Type of input to use for meter search <span
     class='property-internal'>One of Address, SerialNumber </span>
    :type search_type: str
    :param addresses: List of premise ids to search for <span
     class='property-internal'>Required when SearchType is set to
     Address</span><span class='property-internal'>List cannot be empty</span>
    :type addresses: list[str]
    :param serial_numbers: List of serial numbers to search for <span
     class='property-internal'>Required when SearchType is set to
     SerialNumber</span><span class='property-internal'>List cannot be
     empty</span>
    :type serial_numbers: list[str]
    """

    _attribute_map = {
        'search_type': {'key': 'searchType', 'type': 'str'},
        'addresses': {'key': 'addresses', 'type': '[str]'},
        'serial_numbers': {'key': 'serialNumbers', 'type': '[str]'},
    }

    def __init__(self, **kwargs):
        super(MeterSearchRequest, self).__init__(**kwargs)
        self.search_type = kwargs.get('search_type', None)
        self.addresses = kwargs.get('addresses', None)
        self.serial_numbers = kwargs.get('serial_numbers', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BenchmarkValuesResponse(Model):
    """BenchmarkValuesResponse.

    :param benchmark_values: List of benchmark values and their effective
     dates <span class='property-internal'>Required (defined)</span>
    :type benchmark_values: list[~energycap.sdk.models.BenchmarkValue]
    :param benchmark_indicator: Indicator for which benchmark factor <span
     class='property-internal'>Required (defined)</span>
    :type benchmark_indicator: int
    :param benchmark_info: benchmark info <span
     class='property-internal'>Required (defined)</span>
    :type benchmark_info: str
    :param benchmark_category:
    :type benchmark_category: ~energycap.sdk.models.BenchmarkCategoryResponse
    """

    _attribute_map = {
        'benchmark_values': {'key': 'benchmarkValues', 'type': '[BenchmarkValue]'},
        'benchmark_indicator': {'key': 'benchmarkIndicator', 'type': 'int'},
        'benchmark_info': {'key': 'benchmarkInfo', 'type': 'str'},
        'benchmark_category': {'key': 'benchmarkCategory', 'type': 'BenchmarkCategoryResponse'},
    }

    def __init__(self, *, benchmark_values=None, benchmark_indicator: int=None, benchmark_info: str=None, benchmark_category=None, **kwargs) -> None:
        super(BenchmarkValuesResponse, self).__init__(**kwargs)
        self.benchmark_values = benchmark_values
        self.benchmark_indicator = benchmark_indicator
        self.benchmark_info = benchmark_info
        self.benchmark_category = benchmark_category



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GenericCount(Model):
    """GenericCount.

    :param count: Number of items
    :type count: int
    :param description: A short description of the items counted
    :type description: str
    """

    _attribute_map = {
        'count': {'key': 'count', 'type': 'int'},
        'description': {'key': 'description', 'type': 'str'},
    }

    def __init__(self, *, count: int=None, description: str=None, **kwargs) -> None:
        super(GenericCount, self).__init__(**kwargs)
        self.count = count
        self.description = description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountMeterRateResponse(Model):
    """AccountMeterRateResponse.

    :param rate_id: The account meter tariff identifier <span
     class='property-internal'>Required (defined)</span>
    :type rate_id: int
    :param name: The rate name <span class='property-internal'>Required
     (defined)</span>
    :type name: str
    :param rate_code: The rate code <span class='property-internal'>Required
     (defined)</span>
    :type rate_code: str
    :param note: The rate's note <span class='property-internal'>Required
     (defined)</span>
    :type note: str
    :param start_date: The start date for the rate on the account meter <span
     class='property-internal'>Required (defined)</span>
    :type start_date: datetime
    :param end_date: The end date for the rate on the account meter <span
     class='property-internal'>Required (defined)</span>
    :type end_date: datetime
    """

    _attribute_map = {
        'rate_id': {'key': 'rateId', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'rate_code': {'key': 'rateCode', 'type': 'str'},
        'note': {'key': 'note', 'type': 'str'},
        'start_date': {'key': 'startDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(AccountMeterRateResponse, self).__init__(**kwargs)
        self.rate_id = kwargs.get('rate_id', None)
        self.name = kwargs.get('name', None)
        self.rate_code = kwargs.get('rate_code', None)
        self.note = kwargs.get('note', None)
        self.start_date = kwargs.get('start_date', None)
        self.end_date = kwargs.get('end_date', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlaceSubmissionStatusChild(Model):
    """EnergyStarPlaceSubmissionStatusChild.

    :param submission_period: The submission period
    :type submission_period: int
    :param submission_period_display_name: The submission period display name.
     Only populated if the submission period has a custom name.
    :type submission_period_display_name: str
    :param submission_status: The submission status:
     Submitted  - submission has been made for this place and submission period
     Incomplete - no submission has been made for this place and submission
     period, and current billing data is incomplete
     Ready      - no submission has been made for this place and submission
     period, and current billing data is complete
    :type submission_status: str
    """

    _attribute_map = {
        'submission_period': {'key': 'submissionPeriod', 'type': 'int'},
        'submission_period_display_name': {'key': 'submissionPeriodDisplayName', 'type': 'str'},
        'submission_status': {'key': 'submissionStatus', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarPlaceSubmissionStatusChild, self).__init__(**kwargs)
        self.submission_period = kwargs.get('submission_period', None)
        self.submission_period_display_name = kwargs.get('submission_period_display_name', None)
        self.submission_status = kwargs.get('submission_status', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillImportWorkflowSettings(Model):
    """Represents workflow settings for bill imports.

    :param error_handling: Determines how bill import errors are handled <span
     class='property-internal'>One of MarkBatchPending, ProcessValidBills
     </span>
    :type error_handling: str
    """

    _attribute_map = {
        'error_handling': {'key': 'errorHandling', 'type': 'str'},
    }

    def __init__(self, *, error_handling: str=None, **kwargs) -> None:
        super(BillImportWorkflowSettings, self).__init__(**kwargs)
        self.error_handling = error_handling



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountPeriodRequest(Model):
    """AccountPeriodRequest.

    All required parameters must be populated in order to send to Azure.

    :param period_number: The period number
     When submitted with a list of other account periods, there cannot be more
     than one account period with the same periodNumber <span
     class='property-internal'>Must be between 1 and 12</span> <span
     class='property-internal'>Required (defined)</span>
    :type period_number: int
    :param name: Required. The name of the period <span
     class='property-internal'>Required (defined)</span>
    :type name: str
    """

    _validation = {
        'period_number': {'maximum': 12, 'minimum': 1},
        'name': {'required': True, 'max_length': 32},
    }

    _attribute_map = {
        'period_number': {'key': 'periodNumber', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AccountPeriodRequest, self).__init__(**kwargs)
        self.period_number = kwargs.get('period_number', None)
        self.name = kwargs.get('name', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportDistributionEmailSettings(Model):
    """ReportDistributionEmailSettings.

    :param reply_to_email: The email address the receiver should reply to
    :type reply_to_email: str
    :param recipient_user_groups: The list of user groups that should receive
     the report
    :type recipient_user_groups: list[~energycap.sdk.models.UserGroupChild]
    :param email_subject: The subject line of the email
    :type email_subject: str
    :param email_message: The body of the email
    :type email_message: str
    :param report_format: Format of the report (EnergyCAP currently supports
     PDF, Word, Excel, and CSV)
    :type report_format: str
    :param schedule_type:
    :type schedule_type:
     ~energycap.sdk.models.ReportSubscriptionScheduleTypeChild
    :param day_indicator:
    :type day_indicator:
     ~energycap.sdk.models.ReportSubscriptionDayIndicatorChild
    :param only_send_if_data: Indicates whether or not to email a report if it
     contains no data.
     When set to true, the subscribed report will not be emailed, if the report
     does not contain data.
     When set to false, if the requested report has no data, it will still be
     sent.
    :type only_send_if_data: bool
    """

    _attribute_map = {
        'reply_to_email': {'key': 'replyToEmail', 'type': 'str'},
        'recipient_user_groups': {'key': 'recipientUserGroups', 'type': '[UserGroupChild]'},
        'email_subject': {'key': 'emailSubject', 'type': 'str'},
        'email_message': {'key': 'emailMessage', 'type': 'str'},
        'report_format': {'key': 'reportFormat', 'type': 'str'},
        'schedule_type': {'key': 'scheduleType', 'type': 'ReportSubscriptionScheduleTypeChild'},
        'day_indicator': {'key': 'dayIndicator', 'type': 'ReportSubscriptionDayIndicatorChild'},
        'only_send_if_data': {'key': 'onlySendIfData', 'type': 'bool'},
    }

    def __init__(self, *, reply_to_email: str=None, recipient_user_groups=None, email_subject: str=None, email_message: str=None, report_format: str=None, schedule_type=None, day_indicator=None, only_send_if_data: bool=None, **kwargs) -> None:
        super(ReportDistributionEmailSettings, self).__init__(**kwargs)
        self.reply_to_email = reply_to_email
        self.recipient_user_groups = recipient_user_groups
        self.email_subject = email_subject
        self.email_message = email_message
        self.report_format = report_format
        self.schedule_type = schedule_type
        self.day_indicator = day_indicator
        self.only_send_if_data = only_send_if_data



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ApprovalWorkflowSettings(Model):
    """ApprovalWorkflowSettings.

    :param approval_mode_enabled:
    :type approval_mode_enabled: bool
    :param confirm_edit_delete:
    :type confirm_edit_delete: bool
    :param maximum_approval_amount:
    :type maximum_approval_amount: int
    """

    _attribute_map = {
        'approval_mode_enabled': {'key': 'approvalModeEnabled', 'type': 'bool'},
        'confirm_edit_delete': {'key': 'confirmEditDelete', 'type': 'bool'},
        'maximum_approval_amount': {'key': 'maximumApprovalAmount', 'type': 'int'},
    }

    def __init__(self, *, approval_mode_enabled: bool=None, confirm_edit_delete: bool=None, maximum_approval_amount: int=None, **kwargs) -> None:
        super(ApprovalWorkflowSettings, self).__init__(**kwargs)
        self.approval_mode_enabled = approval_mode_enabled
        self.confirm_edit_delete = confirm_edit_delete
        self.maximum_approval_amount = maximum_approval_amount



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FixedAmountResponse(Model):
    """Fixed amount per unit to apply during bill calculation.

    :param amount: Fixed amount
    :type amount: float
    :param unit:
    :type unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'amount': {'key': 'amount', 'type': 'float'},
        'unit': {'key': 'unit', 'type': 'UnitChild'},
    }

    def __init__(self, **kwargs):
        super(FixedAmountResponse, self).__init__(**kwargs)
        self.amount = kwargs.get('amount', None)
        self.unit = kwargs.get('unit', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UDFSelectValueResponse(Model):
    """UDFSelectValueResponse.

    :param udf_select_value_id:
    :type udf_select_value_id: int
    :param value:
    :type value: str
    :param display_order:
    :type display_order: int
    :param count:
    :type count: int
    """

    _attribute_map = {
        'udf_select_value_id': {'key': 'udfSelectValueId', 'type': 'int'},
        'value': {'key': 'value', 'type': 'str'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
        'count': {'key': 'count', 'type': 'int'},
    }

    def __init__(self, *, udf_select_value_id: int=None, value: str=None, display_order: int=None, count: int=None, **kwargs) -> None:
        super(UDFSelectValueResponse, self).__init__(**kwargs)
        self.udf_select_value_id = udf_select_value_id
        self.value = value
        self.display_order = display_order
        self.count = count



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculatedBillCostRequest(Model):
    """Defines how use is calculated for a calculated bill distribution.

    :param use_current_meters_rate_schedule: Apply the meter's current rate
     when calculating bill cost
     "true" is the only valid value for this property <span
     class='property-internal'>One of True </span> <span
     class='property-internal'>Required (defined)</span>
    :type use_current_meters_rate_schedule: bool
    :param fixed_unit_cost:
    :type fixed_unit_cost: ~energycap.sdk.models.FixedUnitCostRequest
    :param unit_cost_meter_id: MeterId from where to get the unit cost <span
     class='property-internal'>Required (defined)</span>
    :type unit_cost_meter_id: int
    :param fixed_amount: Use a fixed amount for bill cost <span
     class='property-info'>Max scale of 2</span> <span
     class='property-info'>NULL Valid</span> <span
     class='property-internal'>Required (defined)</span>
    :type fixed_amount: float
    :param copy_cost_from_meter:
    :type copy_cost_from_meter: ~energycap.sdk.models.CopyMeterRequest
    :param cost_calculation:
    :type cost_calculation: ~energycap.sdk.models.CalculationRequest
    :param calendarized_cost_calculation:
    :type calendarized_cost_calculation:
     ~energycap.sdk.models.CalendarizedCalculationRequest
    """

    _attribute_map = {
        'use_current_meters_rate_schedule': {'key': 'useCurrentMetersRateSchedule', 'type': 'bool'},
        'fixed_unit_cost': {'key': 'fixedUnitCost', 'type': 'FixedUnitCostRequest'},
        'unit_cost_meter_id': {'key': 'unitCostMeterId', 'type': 'int'},
        'fixed_amount': {'key': 'fixedAmount', 'type': 'float'},
        'copy_cost_from_meter': {'key': 'copyCostFromMeter', 'type': 'CopyMeterRequest'},
        'cost_calculation': {'key': 'costCalculation', 'type': 'CalculationRequest'},
        'calendarized_cost_calculation': {'key': 'calendarizedCostCalculation', 'type': 'CalendarizedCalculationRequest'},
    }

    def __init__(self, *, use_current_meters_rate_schedule: bool=None, fixed_unit_cost=None, unit_cost_meter_id: int=None, fixed_amount: float=None, copy_cost_from_meter=None, cost_calculation=None, calendarized_cost_calculation=None, **kwargs) -> None:
        super(CalculatedBillCostRequest, self).__init__(**kwargs)
        self.use_current_meters_rate_schedule = use_current_meters_rate_schedule
        self.fixed_unit_cost = fixed_unit_cost
        self.unit_cost_meter_id = unit_cost_meter_id
        self.fixed_amount = fixed_amount
        self.copy_cost_from_meter = copy_cost_from_meter
        self.cost_calculation = cost_calculation
        self.calendarized_cost_calculation = calendarized_cost_calculation



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActionableBillCounts(Model):
    """ActionableBillCounts.

    :param export_hold_count: Count of bills Held from Export
    :type export_hold_count: int
    :param ap_export_count: Count of bills Waiting for Export to AP
    :type ap_export_count: int
    :param gl_export_count: Count of bills Waiting for Export to GL
    :type gl_export_count: int
    :param approval_count: Count of bills which are Not Approved
    :type approval_count: int
    :param audit_problem_count: Count of bills with unresolved flags
    :type audit_problem_count: int
    """

    _attribute_map = {
        'export_hold_count': {'key': 'exportHoldCount', 'type': 'int'},
        'ap_export_count': {'key': 'apExportCount', 'type': 'int'},
        'gl_export_count': {'key': 'glExportCount', 'type': 'int'},
        'approval_count': {'key': 'approvalCount', 'type': 'int'},
        'audit_problem_count': {'key': 'auditProblemCount', 'type': 'int'},
    }

    def __init__(self, *, export_hold_count: int=None, ap_export_count: int=None, gl_export_count: int=None, approval_count: int=None, audit_problem_count: int=None, **kwargs) -> None:
        super(ActionableBillCounts, self).__init__(**kwargs)
        self.export_hold_count = export_hold_count
        self.ap_export_count = ap_export_count
        self.gl_export_count = gl_export_count
        self.approval_count = approval_count
        self.audit_problem_count = audit_problem_count



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LoginRequest(Model):
    """LoginRequest.

    All required parameters must be populated in order to send to Azure.

    :param data_source: Required. Datasource <span
     class='property-internal'>Required</span>
    :type data_source: str
    :param password: Required. Password <span
     class='property-internal'>Required</span>
    :type password: str
    :param username: Required. Username <span
     class='property-internal'>Required</span>
    :type username: str
    :param partition: OPTIONAL - Partition
     Usually this is the environment, Staging, Pro, Web.
     An empty or NULL partition will result in all partitions being scanned.
    :type partition: str
    """

    _validation = {
        'data_source': {'required': True},
        'password': {'required': True},
        'username': {'required': True},
    }

    _attribute_map = {
        'data_source': {'key': 'dataSource', 'type': 'str'},
        'password': {'key': 'password', 'type': 'str'},
        'username': {'key': 'username', 'type': 'str'},
        'partition': {'key': 'partition', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(LoginRequest, self).__init__(**kwargs)
        self.data_source = kwargs.get('data_source', None)
        self.password = kwargs.get('password', None)
        self.username = kwargs.get('username', None)
        self.partition = kwargs.get('partition', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdminSettingsResponse(Model):
    """AdminSettingsResponse.

    :param field_name: The setting field
    :type field_name: str
    :param value: The setting value
    :type value: str
    :param data_type:
    :type data_type: ~energycap.sdk.models.DataTypeResponse
    """

    _attribute_map = {
        'field_name': {'key': 'fieldName', 'type': 'str'},
        'value': {'key': 'value', 'type': 'str'},
        'data_type': {'key': 'dataType', 'type': 'DataTypeResponse'},
    }

    def __init__(self, **kwargs):
        super(AdminSettingsResponse, self).__init__(**kwargs)
        self.field_name = kwargs.get('field_name', None)
        self.value = kwargs.get('value', None)
        self.data_type = kwargs.get('data_type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackTaskRequest(Model):
    """ChargebackTaskRequest.

    All required parameters must be populated in order to send to Azure.

    :param comment: Required. Comment to add to the task <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type comment: str
    """

    _validation = {
        'comment': {'required': True, 'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'comment': {'key': 'comment', 'type': 'str'},
    }

    def __init__(self, *, comment: str, **kwargs) -> None:
        super(ChargebackTaskRequest, self).__init__(**kwargs)
        self.comment = comment



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChannelVersionWithBeginDateRequest(Model):
    """ChannelVersionWithBeginDateRequest.

    All required parameters must be populated in order to send to Azure.

    :param begin_date: Date the channel version started to be used <span
     class='property-internal'>Must be between 12/30/1899 and 12/31/2099</span>
    :type begin_date: datetime
    :param multiplier: Required. The channel multiplier <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 999999999999999</span>
    :type multiplier: float
    :param unit_code: Required. The channel's unit of measure <span
     class='property-internal'>Required</span>
    :type unit_code: str
    :param observation_rule: Required. The channel's observation rule.
     Possible values include "Odometer" and "Trip" <span
     class='property-internal'>Required</span> <span
     class='property-internal'>One of Odometer, Trip </span>
    :type observation_rule: str
    :param maximum_reading: Required. The channel's max reading <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 999999999999999</span>
    :type maximum_reading: float
    :param udfs: List of user defined/custom fields and values for this
     version
     If the Udfs list is null or empty no values are assigned
     If a udf is omitted no value is assigned to that udf
     To remove a value from an existing Udf, pass in the UdfId and set the
     Value to null
    :type udfs: list[~energycap.sdk.models.UDFValue]
    """

    _validation = {
        'multiplier': {'required': True, 'maximum': 999999999999999, 'minimum': 0},
        'unit_code': {'required': True},
        'observation_rule': {'required': True},
        'maximum_reading': {'required': True, 'maximum': 999999999999999, 'minimum': 0},
    }

    _attribute_map = {
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'multiplier': {'key': 'multiplier', 'type': 'float'},
        'unit_code': {'key': 'unitCode', 'type': 'str'},
        'observation_rule': {'key': 'observationRule', 'type': 'str'},
        'maximum_reading': {'key': 'maximumReading', 'type': 'float'},
        'udfs': {'key': 'udfs', 'type': '[UDFValue]'},
    }

    def __init__(self, *, multiplier: float, unit_code: str, observation_rule: str, maximum_reading: float, begin_date=None, udfs=None, **kwargs) -> None:
        super(ChannelVersionWithBeginDateRequest, self).__init__(**kwargs)
        self.begin_date = begin_date
        self.multiplier = multiplier
        self.unit_code = unit_code
        self.observation_rule = observation_rule
        self.maximum_reading = maximum_reading
        self.udfs = udfs



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WeatherImportSettings(Model):
    """WeatherImportSettings.

    :param weather_station_codes: List of weather station codes for which to
     import data
     If omitted or empty, weather data will be imported for all weather
     stations which are assigned to buildings
    :type weather_station_codes: list[str]
    :param begin_date: The begin date for the weather data
     Readings will be imported from this date through the current date
     If omitted or empty, weather data will be imported for the past 31 days
    :type begin_date: datetime
    """

    _attribute_map = {
        'weather_station_codes': {'key': 'weatherStationCodes', 'type': '[str]'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
    }

    def __init__(self, *, weather_station_codes=None, begin_date=None, **kwargs) -> None:
        super(WeatherImportSettings, self).__init__(**kwargs)
        self.weather_station_codes = weather_station_codes
        self.begin_date = begin_date



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BenchmarkEdit(Model):
    """BenchmarkEdit.

    All required parameters must be populated in order to send to Azure.

    :param benchmark_category_id: Required. benchmark category Id <span
     class='property-internal'>Required</span>
    :type benchmark_category_id: int
    :param benchmark_info: Required. benchmark name <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type benchmark_info: str
    """

    _validation = {
        'benchmark_category_id': {'required': True},
        'benchmark_info': {'required': True, 'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'benchmark_category_id': {'key': 'benchmarkCategoryId', 'type': 'int'},
        'benchmark_info': {'key': 'benchmarkInfo', 'type': 'str'},
    }

    def __init__(self, *, benchmark_category_id: int, benchmark_info: str, **kwargs) -> None:
        super(BenchmarkEdit, self).__init__(**kwargs)
        self.benchmark_category_id = benchmark_category_id
        self.benchmark_info = benchmark_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SavingsLog(Model):
    """SavingsLog.

    :param status: The status of savings processing
    :type status: str
    :param success_count: Number of meters successfully processed
    :type success_count: int
    :param warning_count: Number of bills processed that have warnings across
     all meters processed
     A bill has a "warning" if it had 1) incomplete weather data or 2) exceeded
     the average unit cost range set for its commodity
    :type warning_count: int
    :param error_count: Number of meters processed with errors
    :type error_count: int
    :param number_of_meters: Number of meters to process
    :type number_of_meters: int
    """

    _attribute_map = {
        'status': {'key': 'status', 'type': 'str'},
        'success_count': {'key': 'successCount', 'type': 'int'},
        'warning_count': {'key': 'warningCount', 'type': 'int'},
        'error_count': {'key': 'errorCount', 'type': 'int'},
        'number_of_meters': {'key': 'numberOfMeters', 'type': 'int'},
    }

    def __init__(self, *, status: str=None, success_count: int=None, warning_count: int=None, error_count: int=None, number_of_meters: int=None, **kwargs) -> None:
        super(SavingsLog, self).__init__(**kwargs)
        self.status = status
        self.success_count = success_count
        self.warning_count = warning_count
        self.error_count = error_count
        self.number_of_meters = number_of_meters



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterGroupChild(Model):
    """MeterGroupChild.

    :param meter_group_id: The meter group identifier
    :type meter_group_id: int
    :param meter_group_code: The meter group code
    :type meter_group_code: str
    :param meter_group_info: The meter group info
    :type meter_group_info: str
    :param auto_group: Indicates if this meter group is an autogroup
    :type auto_group: bool
    :param user_defined_auto_group: Indicates if this meter group is an user
     defined auto group
    :type user_defined_auto_group: bool
    """

    _attribute_map = {
        'meter_group_id': {'key': 'meterGroupId', 'type': 'int'},
        'meter_group_code': {'key': 'meterGroupCode', 'type': 'str'},
        'meter_group_info': {'key': 'meterGroupInfo', 'type': 'str'},
        'auto_group': {'key': 'autoGroup', 'type': 'bool'},
        'user_defined_auto_group': {'key': 'userDefinedAutoGroup', 'type': 'bool'},
    }

    def __init__(self, *, meter_group_id: int=None, meter_group_code: str=None, meter_group_info: str=None, auto_group: bool=None, user_defined_auto_group: bool=None, **kwargs) -> None:
        super(MeterGroupChild, self).__init__(**kwargs)
        self.meter_group_id = meter_group_id
        self.meter_group_code = meter_group_code
        self.meter_group_info = meter_group_info
        self.auto_group = auto_group
        self.user_defined_auto_group = user_defined_auto_group
